==> fmpsdk-20201224.0-py3-none-any.whl: fmpsdk/settings.py <==
import typing

BASE_URL: str = "https://financialmodelingprep.com/api/v3/"

DEFAULT_LIMIT: int = 10
INDUSTRY_VALUES: typing.List = [
    "Banks",
    "Energy",
    "Materials",
    "Consumer Electronics",
    "Software Infrastructure",
    "Internet Retail",
    "Internet Content & Information",
    "Auto Manufacturers",
    "Insurance Diversified",
    "Food & Staples Retailing",
    "",
    "Semiconductors",
    "Credit Services",
    "Discount Stores",
    "Drug Manufacturers General",
    "Banks Diversified",
    "Household & Personal Products",
    "Health Care Plans",
    "Entertainment",
    "Home Improvement Retail",
    "Luxury Goods",
    "Telecom Services",
    "Beverages Non-Alcoholic",
    "Footwear & Accessories",
    "Software Application",
    "Semiconductor Equipment & Materials",
    "Medical Devices",
    "Communication Equipment",
    "Diagnostics & Research",
    "Oil & Gas Integrated",
    "Communication Services",
    "Information Technology Services",
    "Other Industrial Metals & Mining",
    "Biotechnology",
    "Restaurants",
    "Integrated Freight & Logistics",
    "Specialty Industrial Machinery",
    "Utilities Regulated Electric",
    "Beverages Alcoholic",
    "Railroads",
    "Specialty Chemicals",
    "Insurance Life",
    "Aerospace & Defense",
    "Tobacco",
    "Asset Management",
    "Chemicals",
    "Capital Markets",
    "Beverages Brewers",
    "REIT Specialty",
    "Farm & Heavy Construction Machinery",
    "Electronic Gaming & Multimedia",
    "Medical Instruments & Supplies",
    "Beverages Wineries & Distilleries",
    "Metals & Mining",
    "Travel Services",
    "Oil & Gas Midstream",
    "Confectioners",
    "Apparel Retail",
    "Drug Manufacturers General Specialty & Generic",
    "Financial Data & Stock Exchanges",
    "Staffing & Employment Services",
    "Transportation",
    "REIT Industrial",
    "Banks Regional",
    "Insurance Property & Casualty",
    "Medical Instruments & Equipment",
    "Oil & Gas E&P",
    "Gold",
    "Utilities Diversified",
    "Specialty Business Services",
    "Insurance Brokers",
    "Computer Hardware",
    "Agriculture",
    "Medical Care Facilities",
    "Software—Infrastructure",
    "Insurance",
    "Consulting Services",
    "Copper",
    "Waste Management",
    "Grocery Stores",
    "Leisure",
    "Publishing",
    "Engineering & Construction",
    "Software—Application",
    "Resorts & Casinos",
    "Health Information Services",
    "Consumer Packaged Goods",
    "Lodging",
    "Auto Parts",
    "Education & Training Services",
    "Electronic Components",
    "REIT Office",
    "Food Distribution",
    "Business Services",
    "Autos",
    "Packaged Foods",
    "Real Estate Services",
    "Retail Apparel & Specialty",
    "Oil & Gas Services",
    "Pharmaceutical Retailers",
    "Agricultural Inputs",
    "Building Materials",
    "Specialty Retail",
    "Insurance Reinsurance",
    "Building Products & Equipment",
    "Apparel Manufacturing",
    "Oil & Gas Equipment & Services",
    "Oil & Gas Refining & Marketing",
    "Packaging & Containers",
    "Tools & Accessories",
    "Broadcasting",
    "Industrial Distribution",
    "Airlines",
    "REIT Retail",
    "Farm Products",
    "Medical Distribution",
    "Utilities Regulated Water",
    "REIT Healthcare Facilities",
    "Residential Construction",
    "Steel",
    "Scientific & Technical Instruments",
    "Trucking",
    "Solar",
    "REIT Residential",
    "Drug Manufacturersâ€”Specialty & Generic",
    "Gambling",
    "Automobiles & Components",
    "Personal Services",
    "Utilities Renewable",
    "Utilities Regulated",
    "Health Care Equipment & Services",
    "Conglomerates",
    "Rental & Leasing Services",
    "REITs",
    "Auto & Truck Dealerships",
    "Electrical Equipment & Parts",
    "Paper & Paper Products",
    "REIT Diversified",
    "Advertising Agencies",
    "Drug Manufacturers—Specialty & Generic",
    "Utilitiesâ€”Renewable",
    "Business Equipment & Supplies",
    "Furnishings, Fixtures & Appliances",
    "Medical Diagnostics & Research",
    "REIT Mortgage",
    "Industrial Products",
    "Utilities Regulated Gas",
    "Utilities Independent Power Producers",
    "Insurance Specialty",
    "Tobacco Products",
    "Softwareâ€”Application",
    "Security & Protection Services",
    "Online Media",
    "Airports & Air Services",
    "REIT Hotel & Motel",
    "Forest Products",
    "Pollution & Treatment Controls",
    "Silver",
    "Travel & Leisure",
    "Oil & Gas Drilling",
    "Recreational Vehicles",
    "Electronics & Computer Distribution",
    "Financial Conglomerates",
    "Uranium",
    "Department Stores",
    "Transportation & Logistics",
    "REITâ€”Residential",
    "Manufacturing Apparel & Furniture",
    "Lumber & Wood Production",
    "Independent Oil & Gas",
    "Health Care Providers",
    "Shell Companies",
    "Metal Fabrication",
    "Mortgage Finance",
    "Insuranceâ€”Property & Casualty",
    "Real Estate Diversified",
    "Utilitiesâ€”Regulated Gas",
    "Aluminum",
    "Banksâ€”Regional",
    "Other Precious Metals & Mining",
    "Marine Shipping",
    "N/A",
    "REITâ€”Diversified",
    "Infrastructure Operations",
    "Real Estate Development",
    "Consulting & Outsourcing",
    "Textile Manufacturing",
    "Pharmaceuticals, Biotechnology & Life Sciences",
    "Coal",
    "Real Estate",
    "Softwarare Application",
    "Brokers & Exchanges",
    "Education",
    "Retail Defensive",
    "Homebuilding & Construction",
    "Employment Services",
    "Coking Coal",
    "Diversified Financials",
    "Thermal Coal",
    "Software & Services",
    "Utilities—Regulated Water",
    "Closed-End Fund Debt",
    "Media & Entertainment",
    "Advertising & Marketing Services",
    "Industrial Metals & Minerals",
    "Utilities",
    "Farm & Construction Machinery",
    "Food, Beverage & Tobacco",
    "Real Estateâ€”Development",
    "Property Management",
    "Consumer Services",
    "Capital Goods",
    "Industrial Electrical Equipment",
    "Commercial  & Professional Services",
    "Retailing",
    "Apparel Stores",
    "Mortgage Investment",
    "Electronics Wholesale",
    "Auto Dealerships",
]
SECTOR_VALUES: typing.List = [
    "Consumer Cyclical",
    "Energy",
    "Technology",
    "Industrials",
    "Financial Services",
    "Basic Materials",
    "Communication Services",
    "Consumer Defensive",
    "Healthcare",
    "Real Estate",
    "Utilities",
    "Industrial Goods",
    "Financial Services",
    "Conglomerates",
]
PERIOD_VALUES: typing.List = [
    "annual",
    "quarter",
]
EXCHANGE_VALUES: typing.List = [
    "ETF",
    "MUTUAL_FUND",
    "COMMODITY",
    "INDEX",
    "CRYPTO",
    "FOREX",
    "TSX",
    "AMEX",
    "NASDAQ",
    "NYSE",
    "EURONEXT",
]
TIME_DELTA_VALUES: typing.List = [
    "1min",
    "5min",
    "15min",
    "30min",
    "1hour",
    "4hour",
]
TECHNICAL_INDICATORS_TIME_DELTA_VALUES: typing.List = [
    "1min",
    "5min",
    "15min",
    "30min",
    "1hour",
    "4hour",
    "daily",
]
SERIES_TYPE_VALUES: typing.List = [
    "line",
]
STATISTICS_TYPE_VALUES: typing.List = [
    "sma",
    "ema",
    "wma",
    "dema",
    "tema",
    "williams",
    "rsa",
    "adx",
    "standardDeviation",
]

FINANCIAL_STATEMENT_FILENAME: str = "financial_statement.zip"
CASH_FLOW_STATEMENT_FILENAME: str = "cash_flow_statement.csv"
INCOME_STATEMENT_FILENAME: str = "income_statement.csv"
BALANCE_SHEET_STATEMENT_FILENAME: str = "balance_sheet_statement.csv"
INCOME_STATEMENT_AS_REPORTED_FILENAME: str = "income_statement_as_reported.csv"
BALANCE_SHEET_STATEMENT_AS_REPORTED_FILENAME: str = "balance_sheet_as_reported.csv"
CASH_FLOW_STATEMENT_AS_REPORTED_FILENAME: str = "cash_flow_as_reported.csv"
SEC_RSS_FEEDS_FILENAME: str = "sec_rss_feeds.csv"
SP500_CONSTITUENTS_FILENAME: str = "sp500_constituents.csv"
NASDAQ_CONSTITUENTS_FILENAME: str = "nasdaq_constituents.csv"
DOWJONES_CONSTITUENTS_FILENAME: str = "dowjones_constituents.csv"

==> fmpsdk-20201229.0-py3-none-any.whl: fmpsdk/settings.py <==
import typing

BASE_URL: str = "https://financialmodelingprep.com/api/v3/"

DEFAULT_LIMIT: int = 10
INDUSTRY_VALUES: typing.List = [
    "Entertainment",
    "Oil & Gas Midstream",
    "Semiconductors",
    "Specialty Industrial Machinery",
    "Banks Diversified",
    "Consumer Electronics",
    "Software Infrastructure",
    "Broadcasting",
    "Computer Hardware",
    "Building Materials",
    "Resorts & Casinos",
    "Auto Manufacturers",
    "Internet Content & Information",
    "Insurance Diversified",
    "Telecom Services",
    "Metals & Mining",
    "Capital Markets",
    "Steel",
    "Footwear & Accessories",
    "Household & Personal Products",
    "Other Industrial Metals & Mining",
    "Oil & Gas E&P",
    "Banks Regional",
    "Drug Manufacturers General",
    "Internet Retail",
    "Communication Equipment",
    "Semiconductor Equipment & Materials",
    "Oil & Gas Services",
    "Chemicals",
    "Electronic Gaming & Multimedia",
    "Oil & Gas Integrated",
    "Credit Services",
    "Online Media",
    "Business Services",
    "Biotechnology",
    "Grocery Stores",
    "Oil & Gas Equipment & Services",
    "REITs",
    "Copper",
    "Software Application",
    "Home Improvement Retail",
    "Pharmaceutical Retailers",
    "Communication Services",
    "Oil & Gas Drilling",
    "Electronic Components",
    "Packaged Foods",
    "Information Technology Services",
    "Leisure",
    "Specialty Retail",
    "Oil & Gas Refining & Marketing",
    "Tobacco",
    "Financial Data & Stock Exchanges",
    "Insurance Specialty",
    "Beverages Non-Alcoholic",
    "Asset Management",
    "REIT Diversified",
    "Residential Construction",
    "Travel & Leisure",
    "Gold",
    "Discount Stores",
    "Confectioners",
    "Medical Devices",
    "Banks",
    "Independent Oil & Gas",
    "Airlines",
    "Travel Services",
    "Aerospace & Defense",
    "Retail Apparel & Specialty",
    "Diagnostics & Research",
    "Trucking",
    "Insurance Property & Casualty",
    "Health Care Plans",
    "Consulting Services",
    "Aluminum",
    "Beverages Brewers",
    "REIT Residential",
    "Education & Training Services",
    "Apparel Retail",
    "Railroads",
    "Apparel Manufacturing",
    "Staffing & Employment Services",
    "Utilities Diversified",
    "Agricultural Inputs",
    "Restaurants",
    "Drug Manufacturers General Specialty & Generic",
    "Financial Conglomerates",
    "Personal Services",
    "Thermal Coal",
    "REIT Office",
    "Advertising Agencies",
    "Farm & Heavy Construction Machinery",
    "Consumer Packaged Goods",
    "Publishing",
    "Specialty Chemicals",
    "Engineering & Construction",
    "Utilities Independent Power Producers",
    "Utilities Regulated Electric",
    "Medical Instruments & Supplies",
    "Building Products & Equipment",
    "Packaging & Containers",
    "REIT Mortgage",
    "Department Stores",
    "Insurance Life",
    "Luxury Goods",
    "Auto Parts",
    "Autos",
    "REIT Specialty",
    "Integrated Freight & Logistics",
    "Security & Protection Services",
    "Utilities Regulated Gas",
    "Airports & Air Services",
    "Farm Products",
    "REIT Healthcare Facilities",
    "REIT Industrial",
    "Metal Fabrication",
    "Scientific & Technical Instruments",
    "Solar",
    "REIT Hotel & Motel",
    "Medical Distribution",
    "Medical Care Facilities",
    "Agriculture",
    "Food Distribution",
    "Health Information Services",
    "Industrial Products",
    "REIT Retail",
    "Conglomerates",
    "Health Care Providers",
    "Waste Management",
    "Beverages Wineries & Distilleries",
    "Marine Shipping",
    "Real Estate Services",
    "Tools & Accessories",
    "Auto & Truck Dealerships",
    "Industrial Distribution",
    "Uranium",
    "Lodging",
    "Electrical Equipment & Parts",
    "Gambling",
    "Specialty Business Services",
    "Recreational Vehicles",
    "Furnishings",
    "Fixtures & Appliances",
    "Forest Products",
    "Silver",
    "Business Equipment & Supplies",
    "Medical Instruments & Equipment",
    "Utilities Regulated",
    "Coking Coal",
    "Insurance Brokers",
    "Rental & Leasing Services",
    "Lumber & Wood Production",
    "Medical Diagnostics & Research",
    "Pollution & Treatment Controls",
    "Transportation & Logistics",
    "Other Precious Metals & Mining",
    "Brokers & Exchanges",
    "Beverages Alcoholic",
    "Mortgage Finance",
    "Utilities Regulated Water",
    "Manufacturing Apparel & Furniture",
    "Retail Defensive",
    "Real Estate Development",
    "Paper & Paper Products",
    "Insurance Reinsurance",
    "Homebuilding & Construction",
    "Coal",
    "Electronics & Computer Distribution",
    "Health Care Equipment & Services",
    "Education",
    "Employment Services",
    "Textile Manufacturing",
    "Real Estate Diversified",
    "Consulting & Outsourcing",
    "Utilities Renewable",
    "Tobacco Products",
    "Farm & Construction Machinery",
    "Shell Companies",
    "N/A",
    "Advertising & Marketing Services",
    "Capital Goods",
    "Insurance",
    "Industrial Electrical Equipment",
    "Utilities",
    "Pharmaceuticals",
    "Biotechnology & Life Sciences",
    "Infrastructure Operations",
    "Energy",
    "NULL",
    "Property Management",
    "Auto Dealerships",
    "Apparel Stores",
    "Mortgage Investment",
    "Software & Services",
    "Industrial Metals & Minerals",
    "Media & Entertainment",
    "Diversified Financials",
    "Consumer Services",
    "Commercial  & Professional Services",
    "Electronics Wholesale",
    "Retailing",
    "Automobiles & Components",
    "Materials",
    "Real Estate",
    "Food",
    "Beverage & Tobacco",
    "Closed-End Fund Debt",
    "Transportation",
    "Food & Staples Retailing",
    "Consumer Durables & Apparel",
    "Technology Hardware & Equipment",
    "Telecommunication Services",
    "Semiconductors & Semiconductor Equipment",
]
SECTOR_VALUES: typing.List = [
    "Communication Services",
    "Energy",
    "Technology",
    "Industrials",
    "Financial Services",
    "Basic Materials",
    "Consumer Cyclical",
    "Consumer Defensive",
    "Healthcare",
    "Real Estate",
    "Utilities",
    "Financial",
    "Building",
    "Industrial Goods",
    "Pharmaceuticals",
    "Services",
    "Conglomerates",
    "Media",
    "Banking",
    "Airlines",
    "Retail",
    "Metals & Mining",
    "Textiles",
    "Apparel & Luxury Goods",
    "Chemicals",
    "Biotechnology",
    "Electrical Equipment",
    "Aerospace & Defense",
    "Telecommunication",
    "Machinery",
    "Food Products",
    "Insurance",
    "Logistics & Transportation",
    "Health Care",
    "Beverages",
    "Consumer products",
    "Semiconductors",
    "Automobiles",
    "Trading Companies & Distributors",
    "Commercial Services & Supplies",
    "Construction",
    "Auto Components",
    "Hotels",
    "Restaurants & Leisure",
    "Life Sciences Tools & Services",
    "Communications",
    "Industrial Conglomerates",
    "Professional Services",
    "Road & Rail",
    "Tobacco",
    "Paper & Forest",
    "Packaging",
    "Leisure Products",
    "Transportation Infrastructure",
    "Distributors",
    "Marine",
    "Diversified Consumer Services",
]
PERIOD_VALUES: typing.List = [
    "annual",
    "quarter",
]
EXCHANGE_VALUES: typing.List = [
    "ETF",
    "MUTUAL_FUND",
    "COMMODITY",
    "INDEX",
    "CRYPTO",
    "FOREX",
    "TSX",
    "AMEX",
    "NASDAQ",
    "NYSE",
    "EURONEXT",
]
TIME_DELTA_VALUES: typing.List = [
    "1min",
    "5min",
    "15min",
    "30min",
    "1hour",
    "4hour",
]
TECHNICAL_INDICATORS_TIME_DELTA_VALUES: typing.List = [
    "1min",
    "5min",
    "15min",
    "30min",
    "1hour",
    "4hour",
    "daily",
]
SERIES_TYPE_VALUES: typing.List = [
    "line",
]
STATISTICS_TYPE_VALUES: typing.List = [
    "sma",
    "ema",
    "wma",
    "dema",
    "tema",
    "williams",
    "rsa",
    "adx",
    "standardDeviation",
]

FINANCIAL_STATEMENT_FILENAME: str = "financial_statement.zip"
CASH_FLOW_STATEMENT_FILENAME: str = "cash_flow_statement.csv"
INCOME_STATEMENT_FILENAME: str = "income_statement.csv"
BALANCE_SHEET_STATEMENT_FILENAME: str = "balance_sheet_statement.csv"
INCOME_STATEMENT_AS_REPORTED_FILENAME: str = "income_statement_as_reported.csv"
BALANCE_SHEET_STATEMENT_AS_REPORTED_FILENAME: str = "balance_sheet_as_reported.csv"
CASH_FLOW_STATEMENT_AS_REPORTED_FILENAME: str = "cash_flow_as_reported.csv"
SEC_RSS_FEEDS_FILENAME: str = "sec_rss_feeds.csv"
SP500_CONSTITUENTS_FILENAME: str = "sp500_constituents.csv"
NASDAQ_CONSTITUENTS_FILENAME: str = "nasdaq_constituents.csv"
DOWJONES_CONSTITUENTS_FILENAME: str = "dowjones_constituents.csv"
